==> r-cran-recipes_0.1.9+dfsg.orig.tar.xz: recipes/R/rename_at.R <==
#' Rename multiple columns
#'
#' `step_rename_at` creates a *specification* of a recipe step that will rename
#' the selected variables using a common function.
#'
#' @inheritParams step_center
#' @param fn A function `fun`, a quosure style lambda `~ fun(.)`` or a list of
#' either form (but containing only a single function, see [dplyr::rename_at()]).
#' **Note that this argument must be named**.
#' @param role For model terms created by this step, what analysis role should
#'  they be assigned? By default, the function assumes that the new dimension
#'  columns created by the original variables will be used as predictors in a
#'  model.
#' @param inputs A vector of column names populated by `prep()`.
#' @return An updated version of `recipe` with the new step added to the
#'  sequence of existing steps (if any). For the `tidy` method, a tibble with
#'  columns `terms` which contains the columns being transformed.
#' @keywords datagen
#' @concept preprocessing
#' @concept transformation_methods
#' @export
#' @examples
#' library(dplyr)
#' recipe(~ ., data = iris) %>%
#'   step_rename_at(everything(), fn = ~ gsub(".", "_", ., fixed = TRUE)) %>%
#'   prep() %>%
#'   juice() %>%
#'   slice(1:10)
#' @export
step_rename_at <- function(
  recipe, ...,
  fn,
  role = "predictor",
  trained = FALSE,
  inputs = NULL,
  skip = FALSE,
  id = rand_id("rename_at")
) {

  add_step(
    recipe,
    step_rename_at_new(
      terms = ellipse_check(...),
      fn = fn,
      trained = trained,
      role = role,
      inputs = inputs,
      skip = skip,
      id = id
    )
  )
}

step_rename_at_new <-
  function(terms, fn, role, trained, inputs, skip, id) {
    step(
      subclass = "rename_at",
      terms = terms,
      fn = fn,
      role = role,
      trained = trained,
      inputs = inputs,
      skip = skip,
      id = id
    )
  }

#' @export
prep.step_rename_at <- function(x, training, info = NULL, ...) {
  col_names <- terms_select(x$terms, info = info)
  step_rename_at_new(
    terms = x$terms,
    fn = x$fn,
    trained = TRUE,
    role = x$role,
    inputs = col_names,
    skip = x$skip,
    id = x$id
  )
}

#' @export
bake.step_rename_at <- function(object, new_data, ...) {
  dplyr::rename_at(new_data, .vars = object$inputs, .funs = object$fn)
}

print.step_rename_at <-
  function(x, width = max(20, options()$width - 35), ...) {
    cat("Variable renaming for ", sep = "")
    printer(x$inputs, x$terms, x$trained, width = width)
    invisible(x)
  }

#' @rdname step_rename
#' @export
tidy.step_rename_at <- function(x, ...) {
  if (is_trained(x)) {
    res <- tibble(terms = x$inputs)
  } else {
    term_names <- sel2char(x$terms)
    res <- tibble(terms = term_names)
  }
  res$id <- x$id
  res
}

==> r-cran-recipes_0.1.15+dfsg.orig.tar.xz: recipes/R/rename_at.R <==
#' Rename multiple columns
#'
#' `step_rename_at` creates a *specification* of a recipe step that will rename
#' the selected variables using a common function.
#'
#' @inheritParams step_center
#' @param fn A function `fun`, a quosure style lambda `~ fun(.)`` or a list of
#' either form (but containing only a single function, see [dplyr::rename_at()]).
#' **Note that this argument must be named**.
#' @param role For model terms created by this step, what analysis role should
#'  they be assigned? By default, the function assumes that the new dimension
#'  columns created by the original variables will be used as predictors in a
#'  model.
#' @param inputs A vector of column names populated by `prep()`.
#' @return An updated version of `recipe` with the new step added to the
#'  sequence of existing steps (if any). For the `tidy` method, a tibble with
#'  columns `terms` which contains the columns being transformed.
#' @keywords datagen
#' @concept preprocessing
#' @concept transformation_methods
#' @export
#' @examples
#' library(dplyr)
#' recipe(~ ., data = iris) %>%
#'   step_rename_at(everything(), fn = ~ gsub(".", "_", ., fixed = TRUE)) %>%
#'   prep() %>%
#'   bake(new_data = NULL) %>%
#'   slice(1:10)
#' @export
step_rename_at <- function(
  recipe, ...,
  fn,
  role = "predictor",
  trained = FALSE,
  inputs = NULL,
  skip = FALSE,
  id = rand_id("rename_at")
) {

  add_step(
    recipe,
    step_rename_at_new(
      terms = ellipse_check(...),
      fn = fn,
      trained = trained,
      role = role,
      inputs = inputs,
      skip = skip,
      id = id
    )
  )
}

step_rename_at_new <-
  function(terms, fn, role, trained, inputs, skip, id) {
    step(
      subclass = "rename_at",
      terms = terms,
      fn = fn,
      role = role,
      trained = trained,
      inputs = inputs,
      skip = skip,
      id = id
    )
  }

#' @export
prep.step_rename_at <- function(x, training, info = NULL, ...) {
  col_names <- eval_select_recipes(x$terms, training, info)

  step_rename_at_new(
    terms = x$terms,
    fn = x$fn,
    trained = TRUE,
    role = x$role,
    inputs = col_names,
    skip = x$skip,
    id = x$id
  )
}

#' @export
bake.step_rename_at <- function(object, new_data, ...) {
  dplyr::rename_at(new_data, .vars = object$inputs, .funs = object$fn)
}

print.step_rename_at <-
  function(x, width = max(20, options()$width - 35), ...) {
    cat("Variable renaming for ", sep = "")
    printer(x$inputs, x$terms, x$trained, width = width)
    invisible(x)
  }

#' @rdname step_rename
#' @export
tidy.step_rename_at <- function(x, ...) {
  if (is_trained(x)) {
    res <- tibble(terms = x$inputs)
  } else {
    term_names <- sel2char(x$terms)
    res <- tibble(terms = term_names)
  }
  res$id <- x$id
  res
}
